Package: OpenRepGrid
License: GPL (>= 2)
Title: Tools to Analyze Repertory Grid Data
LazyData: yes
Type: Package
LazyLoad: yes
Authors@R: c(
    person(given = "Mark", family = "Heckmann", email = "heckmann.mark@gmail.com", 
           role = c("aut", "cre", "cph"), comment = c(ORCID = "0000-0002-0736-7417")),
    person(given = "Alejandro", family = "García Gutiérrez", role = "ctb"),
    person(given = "Diego", family = "Vitali", role = "ctb")
    )
Description: Analyze repertory grids, a qualitative-quantitative 
    data collection technique devised by George A. Kelly in the 1950s. Today, grids are used across 
    various domains ranging from clinical psychology to marketing. The package contains functions 
    to quantitatively analyze and visualize repertory grid data (e.g. 'Fransella', 'Bell', & 'Bannister', 
    2004, ISBN: 978-0-470-09080-0). The package is part of the The package is part of the 
    <https://openrepgrid.org/> project.
Version: 0.1.18
Date: 2025-07-08
Encoding: UTF-8
URL: https://github.com/markheckmann/OpenRepGrid
Imports: methods, graphics, grid, utils, stats, grDevices, crayon,
        plyr, stringr, abind, colorspace, psych, XML, pvclust,
        openxlsx, tidyr, dplyr, scales, igraph
Collate: 'bertin.r' 'calc.r' 'data-openrepgrid.r' 'dev-functions.r'
        'distance.R' 'double-entry.R' 'export.r' 'globals.R' 'gmMain.r'
        'gridlist.R' 'import.r' 'measures.r' 'onair.r' 'openrepgrid.r'
        'perturbate.R' 'preferred_poles.R' 'repgrid.r'
        'repgrid-basicops.r' 'repgrid-constructs.r'
        'repgrid-elements.r' 'repgrid-output.r' 'repgrid-plots.r'
        'repgrid-ratings.r' 'resampling.R' 'rgl-3d.r' 'settings.r'
        'utils-import.r' 'utils.r' 'zzz.r'
RoxygenNote: 7.3.2
NeedsCompilation: no
Suggests: rgl, testthat (>= 2.1.0), covr, styler, vdiffr, knitr,
        rmarkdown
Packaged: 2025-07-08 14:46:04 UTC; markheckmann
Author: Mark Heckmann [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-0736-7417>),
  Alejandro García Gutiérrez [ctb],
  Diego Vitali [ctb]
Maintainer: Mark Heckmann <heckmann.mark@gmail.com>
Depends: R (>= 3.5.0)
Repository: CRAN
Date/Publication: 2025-07-08 15:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 20:16:40 UTC; unix
