# Generated by roxygen2: do not edit by hand

S3method("[",openrepgridSettings)
S3method(cbind,repgrid)
S3method(dim,gridlist)
S3method(dim,repgrid)
S3method(drawDetails,gmSplitTextGrob)
S3method(names,repgrid)
S3method(plot,indexDilemma)
S3method(print,alignByLoadings)
S3method(print,constructCor)
S3method(print,constructD)
S3method(print,constructPca)
S3method(print,distance)
S3method(print,elementCor)
S3method(print,gridlist)
S3method(print,hdistance)
S3method(print,indexBieri)
S3method(print,indexConflict1)
S3method(print,indexConflict2)
S3method(print,indexConflict3)
S3method(print,indexDilemma)
S3method(print,indexDilemmatic)
S3method(print,indexIntensity)
S3method(print,indexPolarization)
S3method(print,indexSelfConstruction)
S3method(print,openrepgridSettings)
S3method(print,org.matches)
S3method(print,rmsCor)
S3method(print,ssq)
S3method(print,statsConstructs)
S3method(print,statsElements)
S3method(reorder,repgrid)
S3method(rep,repgrid)
export("constructs<-")
export("elements<-")
export("leftpoles<-")
export("preferredPoles<-")
export("ratings<-")
export("rightpoles<-")
export(addAvgElement)
export(addConstruct)
export(addElement)
export(addIndexColumnToMatrix)
export(addVarianceExplainedToBiplot2d)
export(alignByIdeal)
export(alignByLoadings)
export(alignByPreferredPole)
export(apply_pb)
export(as.gridlist)
export(bertin)
export(bertinCluster)
export(bind)
export(bindConstructs)
export(biplot2d)
export(biplot3d)
export(biplotDraw)
export(biplotEsa2d)
export(biplotEsa3d)
export(biplotEsaPseudo3d)
export(biplotPseudo3d)
export(biplotSimple)
export(biplotSlater2d)
export(biplotSlater3d)
export(biplotSlaterPseudo3d)
export(calcBiplotCoords)
export(calcCoordsBorders)
export(cascade)
export(center)
export(clearRatings)
export(cluster)
export(clusterBoot)
export(constructCor)
export(constructD)
export(constructPca)
export(constructPcaLoadings)
export(constructRmsCor)
export(constructs)
export(convertImportObjectToRepGridObject)
export(convertScivescoImportObjectToRepGridObject)
export(decouple)
export(distance)
export(distanceHartmann)
export(distanceNormalized)
export(distanceSlater)
export(doRectanglesOverlap)
export(doubleEntry)
export(down)
export(elementCor)
export(elementRmsCor)
export(elements)
export(formatMatrix)
export(getConstructNames)
export(getConstructNames2)
export(getElementNames)
export(getElementNames2)
export(getNoOfConstructs)
export(getNoOfElements)
export(getRatingLayer)
export(getScale)
export(getScaleMidpoint)
export(grid_to_df_long)
export(grid_to_df_wide)
export(gridlist)
export(grids_bootstrap)
export(grids_leave_n_out)
export(grids_perturbate)
export(home)
export(importDataframe)
export(importExcel)
export(importGridcor)
export(importGridcorInternal)
export(importGridstat)
export(importGridstatInternal)
export(importGridsuite)
export(importGridsuiteInternal)
export(importScivesco)
export(importScivescoInternal)
export(importTxt)
export(indexBias)
export(indexBieri)
export(indexConflict1)
export(indexConflict2)
export(indexConflict3)
export(indexDDI)
export(indexDilemma)
export(indexDilemmatic)
export(indexIntensity)
export(indexPolarization)
export(indexPvaff)
export(indexSelfConstruction)
export(indexUncertainty)
export(indexVariability)
export(is.gridlist)
export(is.repgrid)
export(lapply_pb)
export(left)
export(leftpoles)
export(makeEmptyRepgrid)
export(makeRepgrid)
export(map)
export(mapCoordinatesToColor)
export(mapCoordinatesToValue)
export(matches)
export(midpoint)
export(modifyConstruct)
export(modifyElement)
export(multigridFileToSinglegridFiles)
export(normalize)
export(orderBy)
export(orderByString)
export(permuteConstructs)
export(permuteGrid)
export(perturbate)
export(preferredPoles)
export(preferredPolesByIdeal)
export(prepareBiplotData)
export(print_square_matrix)
export(quasiDistributionDistanceSlater)
export(randomGrid)
export(randomGrids)
export(randomSentence)
export(randomSentences)
export(randomWords)
export(ratings)
export(ratings_df)
export(recycle)
export(recycle2)
export(reorder2d)
export(reverse)
export(rglDrawConstructLabels)
export(rglDrawConstructPoints)
export(rglDrawStandardAxes)
export(rglDrawStandardEllipses)
export(right)
export(rightpoles)
export(ring)
export(sapply_pb)
export(saveAsExcel)
export(saveAsTxt)
export(saveAsWorksheet)
export(setConstructAttr)
export(setElementAttr)
export(setMeta)
export(setScale)
export(settings)
export(settingsLoad)
export(settingsSave)
export(shift)
export(showScale)
export(slaterStandardization)
export(ssq)
export(statsConstructs)
export(statsElements)
export(stepChart)
export(stop_if_not_0_1_ratings_only)
export(stop_if_not_in_element_range)
export(stop_if_not_is_repgrid)
export(stop_if_scale_not_defined)
export(strReverse)
export(swapConstructs)
export(swapElements)
export(swapPoles)
export(trim_val)
export(up)
exportMethods("+")
exportMethods("/")
import(XML)
import(abind)
import(dplyr)
import(grDevices)
import(graphics)
import(grid)
import(methods)
import(plyr, except = c(failwith,id,count,mutate,desc,rename,summarize,summarise,filter,arrange))
import(psych)
import(pvclust)
import(stats, except=c(lag,filter))
import(stringr)
import(utils)
importFrom(colorspace,HSV)
importFrom(colorspace,diverge_hcl)
importFrom(colorspace,hex)
importFrom(colorspace,hex2RGB)
importFrom(crayon,black)
importFrom(crayon,blue)
importFrom(crayon,bold)
importFrom(crayon,cyan)
importFrom(crayon,green)
importFrom(crayon,magenta)
importFrom(crayon,red)
importFrom(crayon,silver)
importFrom(crayon,white)
importFrom(crayon,yellow)
importFrom(dplyr,case_when)
